@@ -298,32 +298,6 @@ void MainWindow::SetOpacity(QString imagefile, int opacity)
 
 }
 
-void MainWindow::savethemedone()
-{
-    themename = ThemeWin->ui->FileName->text();
-    themedir = themename;
-    themedir = themedir.remove(QChar('\"'));
-    themedir = themedir.remove(QChar(' '));
-    themedir = themedir.simplified();
-    themedir = themedir.toLower();
-    QDir file;
-    file = "/opt/usr/share/themes/" + themedir;
-
-    if (themename.isEmpty()) {
-
-        QMaemo5InformationBox::information(this, tr("You must give name for the theme."), QMaemo5InformationBox::DefaultTimeout);
-
-    } else if (file.exists()) {
-
-        QMaemo5InformationBox::information(this, tr("Folder ") + themedir + tr(" already exists!"), QMaemo5InformationBox::DefaultTimeout);
-
-    } else {
-        ThemeWin->hide();
-        saveasnew = "1";
-        runscript("0");
-    }
-}
-
 void MainWindow::on_pushButton_clicked()
 {
         if ( ui->checkBoxActivate->checkState() == Qt::Checked ) {
@@ -347,17 +321,7 @@ void MainWindow::on_pushButton_clicked()
             Transitions = "0";
         }
 
-        if ( ui->saveasnew->checkState() == Qt::Checked ) {
-
-
-                ThemeWin = new savenewtheme(this);
-                connect(ThemeWin->ui->Save, SIGNAL(clicked()), this, SLOT(savethemedone()));
-                ThemeWin->show();
-
-            } else {
-                saveasnew.clear();
-                runscript("0");
-            }
+        runscript("0");
 
 }
 
@@ -803,7 +767,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-52<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-53<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
@@ -1058,7 +1022,29 @@ void MainWindow::savetheme()
 
     } else if (file.exists()) {
 
-        QMaemo5InformationBox::information(this, tr("Folder ") + themedir + tr(" already exists!"), QMaemo5InformationBox::DefaultTimeout);
+        if (QFile::exists("/opt/usr/share/themes/" + themedir + "/createdbythemecustomizer")) {
+            QMessageBox msgBox;
+            msgBox.setWindowTitle(tr("Overwrite existing theme?"));
+            msgBox.setText(tr("Theme with this name already exists, do you want to overwrite it?"));
+            msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+            msgBox.setDefaultButton(QMessageBox::Yes);
+            msgBox.button(msgBox.Yes)->setText(tr("Yes"));
+            msgBox.button(msgBox.No)->setText(tr("No"));
+            int ret = msgBox.exec();
+
+            if ( ret == QMessageBox::Yes ) {
+
+                ThemeWin->hide();
+                saveasnew = "1";
+                runscript("saveonly");
+
+            }
+
+        } else {
+
+            QMaemo5InformationBox::information(this, tr("Theme ") + themedir + tr(" already exists and cannot be overwritten!"), QMaemo5InformationBox::DefaultTimeout);
+
+        }
 
     } else {
         ThemeWin->hide();
